pub struct FileSeekRequest {
pub origin: SeekOrigin,
pub offset: i64,
}Fields
origin: SeekOriginoffset: i64Trait Implementations
Sourceimpl Clone for FileSeekRequest
impl Clone for FileSeekRequest
Sourcefn clone(&self) -> FileSeekRequest
fn clone(&self) -> FileSeekRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for FileSeekRequest
Sourceimpl Debug for FileSeekRequest
impl Debug for FileSeekRequest
Sourceimpl<___E> Encode<FileSeekRequest, ___E> for FileSeekRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<FileSeekRequest, ___E> for FileSeekRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FileSeekRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FileSeekRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<FileSeekRequest, ___E> for &'a FileSeekRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<FileSeekRequest, ___E> for &'a FileSeekRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FileSeekRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FileSeekRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, FileSeekRequest>, ___E> for FileSeekRequest
impl<___E> EncodeOption<Box<'static, FileSeekRequest>, ___E> for FileSeekRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, FileSeekRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, FileSeekRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, FileSeekRequest>, ___E> for &'a FileSeekRequest
impl<'a, ___E> EncodeOption<Box<'static, FileSeekRequest>, ___E> for &'a FileSeekRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, FileSeekRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, FileSeekRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for FileSeekRequest
Sourceimpl FromWire<FileSeekRequest> for FileSeekRequest
impl FromWire<FileSeekRequest> for FileSeekRequest
Sourcefn from_wire(wire: FileSeekRequest) -> Self
fn from_wire(wire: FileSeekRequest) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<FileSeekRequest> for FileSeekRequest
impl FromWireRef<FileSeekRequest> for FileSeekRequest
Sourcefn from_wire_ref(wire: &FileSeekRequest) -> Self
fn from_wire_ref(wire: &FileSeekRequest) -> Self
Converts the given reference to this type.
Sourceimpl Hash for FileSeekRequest
impl Hash for FileSeekRequest
Sourceimpl Ord for FileSeekRequest
impl Ord for FileSeekRequest
Sourcefn cmp(&self, other: &FileSeekRequest) -> Ordering
fn cmp(&self, other: &FileSeekRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FileSeekRequest
impl PartialEq for FileSeekRequest
Sourcefn eq(&self, other: &FileSeekRequest) -> bool
fn eq(&self, other: &FileSeekRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for FileSeekRequest
impl PartialOrd for FileSeekRequest
impl StructuralPartialEq for FileSeekRequest