ExtendedAttributeIteratorLocalServerHandler

Trait ExtendedAttributeIteratorLocalServerHandler 

pub trait ExtendedAttributeIteratorLocalServerHandler<___T: Transport = Channel> {
    // Required method
    fn get_next(
        &mut self,
        responder: Responder<GetNext, ___T>,
    ) -> impl Future<Output = ()>;
}
A server handler for the ExtendedAttributeIterator protocol.

See ExtendedAttributeIterator for more details.

Required Methods

fn get_next( &mut self, responder: Responder<GetNext, ___T>, ) -> impl Future<Output = ()>

Get the next chunk of extended attribute names. If this is the last chunk, last will be true, and the channel will be closed after the call.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<___H, ___T> ExtendedAttributeIteratorLocalServerHandler<___T> for Local<___H>
where ___H: ExtendedAttributeIteratorServerHandler<___T>, ___T: Transport,

Source

async fn get_next(&mut self, responder: Responder<GetNext, ___T>)

Implementors